@@ -41,8 +41,6 @@
 
 #define KICONTHEMES_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KICONTHEMES_NO_DEPRECATED) && !defined(KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KICONTHEMES_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KICONTHEMES_NO_DEPRECATED
-#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KICONTHEMES_NO_DEPRECATED_WARNINGS
 #  define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KICONTHEMES_DEPRECATED
-#  define KICONTHEMES_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KICONTHEMES_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KICONTHEMES_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
